[−][src]Crate debra_common
Common types, traits and base functionality for the DEBRA reclamation scheme.
This crate forms the common basis for both the debra and debra-simple
crates.
Re-exports
pub use arrayvec; |
pub use reclaim; |
Modules
| bag | Data structures for storing and reclaiming retired records. |
| epoch | Type-safe epoch counters for tracking operations of threads. |
| thread | Concurrently accessible state of threads participating in the reclamation. |
Constants
| EPOCH_CACHE_SIZE | The value of the configurable per-thread size for individual bags storing cached retired records. |
Traits
| LocalAccess | A trait for abstracting over different ways for accessing thread local state. |