BagNode

Struct BagNode 

pub struct BagNode<R: Reclaim + 'static> { /* private fields */ }
A linked list node containing an inline vector for storing retired records.

Panics

Dropping a non-empty BagNode leads to a panic in debug mode.

Implementations

Source

impl<R: Reclaim> BagNode<R>

pub unsafe fn reclaim_all(&mut self)

Reclaims all retired records in this BagNode.

Safety

It must be ensured that the contents of the queue are at least two epochs old.