[][src]Enum debra_common::thread::State

pub enum State {
    Active,
    Inactive,
}

The state of a thread with regards to reading memory.

Variants

Active

The thread is active, i.e. could be currently reading values from shared memory and other threads must not reclaim memory.

Inactive

The thread is currently inactive, i.e. is not currently reading values from shared memory.