[][src]Struct debra_common::thread::ThreadState

pub struct ThreadState(_);

The concurrently accessible state of a thread, containing information about the thread's current Epoch and it's State.

Methods

impl ThreadState[src]

pub fn new(global_epoch: Epoch) -> Self[src]

Creates a new ThreadState for the current global_epoch and in Inactive state.

pub fn is_same(&self, other: &Self) -> bool[src]

Returns true if other is an aliased reference to self.

pub fn load(&self, order: Ordering) -> (Epoch, State)[src]

Loads the thread's current Epoch and its ['State']

load takes an Ordering argument, which describes the memory ordering of this operation.

Panics

Panics if order is Release or AcqRel.

pub fn store(&self, epoch: Epoch, state: State, order: Ordering)[src]

Stores an epoch and a state into the current thread state.

store takes an Ordering argument, which describes the memory ordering of this operation.

Panics

Panics if order is Release or AcqRel.