[−][src]Struct debra_common::bag::BagQueue
A LIFO queue of [RetiredBag]s.
All nodes except the first one are guaranteed to be full and the first one is guaranteed to always have enough space for at least one additional record.
Note
A BagQueue must never be dropped when there are still un-reclaimed
retired records in any of its BagNodes.
Methods
impl<R: Reclaim + 'static> BagQueue<R>[src]
pub fn into_non_empty(self) -> Option<Box<BagNode<R>>>[src]