[−][src]Enum debra_common::thread::State
The state of a thread with regards to reading memory.
Variants
ActiveThe thread is active, i.e. could be currently reading values from shared memory and other threads must not reclaim memory.
InactiveThe thread is currently inactive, i.e. is not currently reading values from shared memory.